@@ -5,7 +5,7 @@ use Carp;
 
 use base 'API::DirectAdmin::Component';
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Return list of users (only usernames)
 sub list {
@@ -190,4 +190,18 @@ sub show_packages {
     return $responce;
 }
 
+# Show user config
+# params: user
+sub show_user_config {
+    my ( $self, $params ) = @_;
+
+    my $responce = $self->directadmin->query(
+	command => 'CMD_API_SHOW_USER_CONFIG',
+	params  => $params,
+	allowed_fields => 'user',
+    );
+
+    return $responce;
+}
+
 1;
